Skip to contents

Convenience: uploads path then writes the resulting file object into the given file/image column of the chosen row.

Usage

hb_attach_file(client, table, row_id, column, path, ...)

Arguments

client

A harbour_client.

table

Table name.

row_id

Row ID.

column

File or image column name.

path

Local file path. Must exist.

...

These dots are for future extensions and must be empty.

Value

Invisibly returns the client.

Examples

if (FALSE) { # interactive()
client <- hb_client()
hb_attach_file(client, "Samples", "abc", "Report", "report.pdf")
}