Update a column
Usage
hb_update_column(
client,
table,
name,
...,
new_name = NULL,
new_type = NULL,
column_data = NULL
)Arguments
- client
A
harbour_client.- table
Table name.
- name
Column name.
- ...
These dots are for future extensions and must be empty.
- new_name
Optional new column name. Sends
op_type = "rename_column".- new_type
Optional new SeaTable column type. Sends
op_type = "modify_column_type". SeaTable performs one operation per request, so this cannot be combined withnew_name.- column_data
Optional list of column options, e.g. the choices for a select column. Named
column_datarather thandatabecausedatameans "the rows you are writing" everywhere else in harbouR.
Examples
if (FALSE) { # interactive()
client <- hb_client()
hb_update_column(client, "Samples", "Notes", new_name = "Comments")
}