Uploads path to the active base and returns the SeaTable file object
(a named list with name, size, type and url) ready to be written
into a file-typed cell via hb_update_rows() or hb_attach_file().
See also
Other files:
hb_attach_file(),
hb_delete_asset(),
hb_download_file()
Examples
if (FALSE) { # interactive()
client <- hb_client()
hb_upload_file(client, "report.pdf")
}